AdvertisementModel class

Constructors

AdvertisementModel({int id = -1, String description = ''})

Properties

description ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromJson(dynamic json, {String? keyName}) → AdvertisementModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited