AdvertisementsModel class

Constructors

AdvertisementsModel()

Properties

hashCode → int
The hash code for this object.
no setterinherited
list → List<AdvertisementModel>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromJson(dynamic json) → AdvertisementsModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited