RepositoryProvider<T> class

Takes a Create function that is responsible for creating the repository and a child which will have access to the repository via RepositoryProvider.of(context). It is used as a dependency injection (DI) widget so that a single instance of a repository can be provided to multiple widgets within a subtree.

RepositoryProvider(
  create: (context) => RepositoryA(),
  child: ChildA(),
);

Lazily creates the repository unless lazy is set to false.

RepositoryProvider(
  lazy: false,`
  create: (context) => RepositoryA(),
  child: ChildA(),
);
Inheritance
Implemented types

Constructors

RepositoryProvider({required Create<T> create, Key? key, Widget? child, bool? lazy})
Takes a Create function that is responsible for creating the repository and a child which will have access to the repository via RepositoryProvider.of(context). It is used as a dependency injection (DI) widget so that a single instance of a repository can be provided to multiple widgets within a subtree.
RepositoryProvider.value({required T value, Key? key, Widget? child})
Takes a repository and a child which will have access to the repository. A new repository should not be created in RepositoryProvider.value. Repositories should always be created using the default constructor within the Create function.

Properties

builder → TransitionBuilder?
Syntax sugar for obtaining a BuildContext that can read the provider created.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
buildWithChild(BuildContext context, Widget? child) → Widget
A build method that receives an extra child parameter.
inherited
createElement() → _InheritedProviderElement<T>
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of<T>(BuildContext context, {bool listen = false}) → T
Method that allows widgets to access a repository instance as long as their BuildContext contains a RepositoryProvider instance.