SharedPreferencesWithCacheOptions class

Options necessary to create a SharedPreferencesWithCache.

Constructors

SharedPreferencesWithCacheOptions({Set<String>? allowList})
Creates a new instance with the given options.
const

Properties

allowList → Set<String>?
Information about what data will be fetched during get and init methods, what data can be set, as well as what data will be removed by clear.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited